#
# spec file for package desktop-translations
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           desktop-translations
Version:        84.87.20241104.9505069
Release:        1.1
Summary:        Desktop Files Translations
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/openSUSE/desktop-file-translations
Source0:        desktop-file-translations-%{version}.tar.xz
Supplements:    bundle-lang-other
Supplements:    gtk2
Supplements:    gtk3
Supplements:    kdelibs3
Supplements:    libkde4
Supplements:    plasma5-desktop
Supplements:    yast2-control-center
Provides:       locale(af;ar;bg;be;bn;bs;ca;cs;cy;da;de;el;en_GB;eo;es;et;fi;fr;gl;gu;he;hi;hr;hu;id;it;ja;ka;kab;km;ko;lo;lt;mk;mr;nb;nl;pa;pl;pt;ro;ru;si;sk;sl;sr;sr@Latn;sv;ta;tr;uk;vi;wa;xh;zh_CN;zh_TW;zu)
BuildRequires:  gettext-runtime
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package provides the translations for installed desktop files.

%package devel
Summary:        Desktop Files Translations po Files

%description devel
This package provides the translations for installed desktop files as po files.

%prep
%setup -q -c %{name}

%build
mv desktop-file-translations-%{version}/* .
./50-tools/build-entries-po.sh

%install
pushd po
mkdir -p %{buildroot}%{_datadir}/%{name}/desktop_translations
for lang in *; do
  if test "$lang" = "nb_no"; then
    continue
  fi
  if test -f $lang; then
	rm $lang
  else
    mkdir -p %{buildroot}%{_datadir}/locale/${lang}/LC_MESSAGES
    for f in ${lang}/*.po; do
       msgfmt -o %{buildroot}%{_datadir}/locale/${lang}/LC_MESSAGES/desktop_translations.mo $f
       msgunfmt --no-wrap %{buildroot}%{_datadir}/locale/${lang}/LC_MESSAGES/desktop_translations.mo | \
          grep -v '^"[A-Z][^ ]*: ' | grep '[^\][\]n"' && exit 1
       cp -a $f %{buildroot}%{_datadir}/%{name}/desktop_translations/${lang}.po
    done
  fi
done
popd

mkdir -p %{buildroot}%{_datadir}/%{name}/polkitaction
for lang in *; do
    if [ -e "${lang}/polkitaction.po" ]; then
	msgfmt -o "%{buildroot}%{_datadir}/locale/${lang}/LC_MESSAGES/polkit-action-distro-translations.mo" "${lang}/polkitaction.po"
	cp -a "${lang}/polkitaction.po" %{buildroot}%{_datadir}/%{name}/polkitaction/${lang}.po
    fi
done

%find_lang %{name} --all-name

%files -f %{name}.lang
%defattr(-,root,root)

%files devel
%defattr(-,root,root)
%{_datadir}/%{name}

%changelog
* Mon Nov  4 2024 opensuse-packaging@opensuse.org
- Update to version 84.87.20241104.9505069
  (after locking of most components in Weblate):
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (German)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Romanian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovenian)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Turkish)
* Wed Sep  4 2024 Stanislav Brabec <sbrabec@suse.com>
- Add support for the new tool %%suse_translate_desktop.
  (boo#1158957)
* Mon Aug 26 2024 Stanislav Brabec <sbrabec@suse.com>
- Generate desktop-translation-devel for purpose of translation
  check. (boo#1158957)
* Fri May  3 2024 opensuse-packaging@opensuse.org
- Update to version 84.87.20240503.9343de5:
  * Update for SLES 15 SP6 RC / Leap 15.6 RC poo#131735
  * Manually remove further invalid character occurances
  * Fix Browse C:\ drive incorrect escaping
* Fri May  3 2024 opensuse-packaging@opensuse.org
- Update to version 84.87.20240502.b932b7c:
  * Add download_data_from_download-o-o.sh
  * Added translation using Weblate (Latvian)
  * Disable appstream and polkit extraction
  * Leap 15.6 desktop-file-translations
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China) (zh_CN))
  * Translated using Weblate (Croatian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (English (United Kingdom))
  * Translated using Weblate (Finnish)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Latvian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Portuguese)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Serbian (latin) (sr@latin))
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Turkish)
* Fri Apr 14 2023 opensuse-packaging@opensuse.org
- Update to version 84.87.20230410.dc72281:
  * Translated using Weblate (Latvian)
  * Translated using Weblate (Latvian)
  * Translated using Weblate (German)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Persian)
  * Translated using Weblate (Persian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
* Mon Feb 13 2023 opensuse-packaging@opensuse.org
- Update to version 84.87.20230128.350400f:
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (German)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Georgian)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Macedonian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Russian)
* Sun May  1 2022 opensuse-packaging@opensuse.org
- Update to version 84.87.20220427.80cb897f:
  * Translated using Weblate (Slovenian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Czech)
* Thu Mar 17 2022 opensuse-packaging@opensuse.org
- Update to version 84.87.20220316.9301f89b:
  * Update strings from Leap 15.4.
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China) (zh_CN))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan) (zh_TW))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Croatian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (Hindi)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Turkish)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Vietnamese)
* Tue Mar  9 2021 opensuse-packaging@opensuse.org
- Update to version 84.87.20210202.7db31a52:
  * Update strings from Leap 15.3.
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Central Atlas Tamazight)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (English (United Kingdom))
  * Translated using Weblate (Finnish)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese)
  * Translated using Weblate (Romanian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Swedish)
  * Added translation using Weblate (Central Atlas Tamazight)
  * Drop obsolete mimelnk files (boo#1062631).
* Thu Mar 12 2020 opensuse-packaging@opensuse.org
- Update to version 84.87.20200312.febbb097:
  * Add two TODO notes to generate_and_merge_pos.sh
  * Drop en_US (boo#1139962, bsc#1163437).
  * README.md: Document the process of update
  * Translated using Weblate (Belarusian)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Estonian)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Turkish)
  * Translated using Weblate (Vietnamese)
  * Update strings from Leap 15.2.
* Tue Sep 24 2019 opensuse-packaging@opensuse.org
- Update to version 84.87.20190924.7050555c:
  * Unfuzzy YaST groups translations
  * fix typo
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (German)
- The following bug was referenced in SLE 15:
  * boo#1037823
* Mon Sep 23 2019 opensuse-packaging@opensuse.org
- Update to version 84.87.20190923.8ea56c56:
  * Regenerate .po files after some more search-replace for YaST
  * Run update-po-files.sh after Leap 15.2 update
  * Update for Leap 15.2 (boo#1145197, bsc#1146886)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (German)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (German)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (German)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Drop "translation" from English to English
  * Remove Indonesian from en_US files
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (German)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese)
  * Translated using Weblate (German)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Portuguese)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Dutch)
  * Update all po files
  * Translated using Weblate (German)
  * Translated using Weblate (Chinese (China))
  * Update update-desktop-files-yast.po
  * Translated using Weblate (Turkish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Lao)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Occidental)
  * Added translation using Weblate (Occidental)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Occidental)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Occidental)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Japanese)
  * Added translation using Weblate (Occidental)
  * Translated using Weblate (Slovak)
  * Added translation using Weblate (Occidental)
  * Translated using Weblate (Slovak)
* Mon May 13 2019 Karl Eichwalder <ke@suse.de>
- Update to version 84.87.20190508.853b49d2:
  * Translated using Weblate (Slovak)
* Mon May  6 2019 Karl Eichwalder <ke@suse.de>
- Update to version 84.87.20190504.726deb37:
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * update translations
* Thu Apr 11 2019 Karl Eichwalder <ke@suse.de>
- Update to version 84.87.20190409.048e157e:
  * Translated using Weblate (Arabic)
  * Translated using Weblate (German)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
* Mon Mar 25 2019 Karl Eichwalder <ke@suse.de>
- Update to version 84.87.20190314.58da68e1:
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (French)
  * Translated using Weblate (Galician)
  * Translated using Weblate (German)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
* Wed Mar  6 2019 Karl Eichwalder <ke@suse.com>
- New language: kab.
* Wed Mar  6 2019 Karl Eichwalder <ke@suse.com>
- Update to version 84.87.20190305.22ea2626:
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Galician)
  * Translated using Weblate (German)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
* Mon Feb 11 2019 ke@suse.com
- Update to version 84.87.20190131.bc9de591:
  * update desktop file data
  * adjust for 15.1
  * Also translate X-SuSE-YaST-Keywords entries in .desktop files
  * Consistently use LF line ending
  * Run generation with new enabled keys
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Galician)
  * Translated using Weblate (German)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Persian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Romanian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Turkish)
  * Update appstreamdata.po
  * Update mimeinfo.po
* Tue May  8 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180507.9a26f9e2:
  * Translated using Weblate (Dutch)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Hindi)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Slovak)
* Tue Apr 24 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180423.2e342f3a:
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Italian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
* Mon Apr 16 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180416.e6c83e49:
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Swedish)
* Wed Mar 21 2018 lnussel@opensuse.org
- Update to version 84.87.20180321.c5ff1117:
  * Merge polkitactions-freedesktop into polkitaction
  * install polkitaction with name used by polkit
  * Don't install unused appstream and mimeinfo files
* Wed Mar 21 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180321.47fa9a4e:
  * Strip whitespace from xml extracted strings
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Swedish)
* Mon Mar 19 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180319.d4e87748:
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Swedish)
  * Update with Leap 15 strings
* Thu Mar  8 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180308.779a35a:
  * Revert "Translated using Weblate (English (United Kingdom))" (bsc#1084392)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (French)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (German)
* Fri Mar  2 2018 opensuse-packaging@opensuse.org
- Update to version 84.87.20180301.7046b3d:
  * Update to 42.3 final
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (German)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (French)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Galician)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Finnish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Italian)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Danish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Serbian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Korean)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (English (United Kingdom))
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Polish)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Marathi)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Korean)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Korean)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (French)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (English (United States))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Hungarian)
  * Translated using Weblate (French)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Zulu)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Danish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Bulgarian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Estonian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Russian)
  * Translated using Weblate (German)
  * Update generate_and_merge_pos.sh
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (German)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Czech)
  * Translated using Weblate (French)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Czech)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Persian)
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
* Wed Jul 19 2017 lnussel@suse.de
- Update to version 84.87.20170719.98170d3:
  * Regenerate PO/POT after "Desktop Action *" section change in tar2po
  * tar2po: Handle "Desktop Action *" sections like "Desktop Entry" (boo#1049021)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
* Thu Jul 13 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170713.beab045:
  * Translated using a text editor + git
* Thu Jul 13 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170713.f60fae5:
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (German)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Chinese (Taiwan))
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Put YaST2.desktop back into update-desktop-files-apps
  * Update POT files after YaST change, sync PO files
* Fri Jul  7 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170705.7bdbb1d:
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Danish)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (German)
  * Translated using Weblate (Italian)
  * Translated using Weblate (German)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (German)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Danish)
  * Translated using Weblate (Norwegian Bokmål)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Relicense 51-xml contents as MIT
  * Translated using Weblate (Norwegian Nynorsk)
  * Translated using Weblate (German)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (German)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (French)
  * Translated using Weblate (German)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (French)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Indonesian)
  * Translated using Weblate (Indonesian)
* Mon Jun 19 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170618.be69114:
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Danish)
  * Translated using Weblate (German)
  * Translated using Weblate (Greek)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Russian)
  * Translated using Weblate (Spanish)
* Wed Jun 14 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170613.caa39e6:
  * Translated using Weblate (Swedish)
  * Translated using Weblate (Swedish)
* Tue Jun 13 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170613.847c686:
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (French)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (French)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Russian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (Ukrainian)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Kabyle)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Chinese (China))
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Danish)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (German)
  * Translated using Weblate (German)
  * Revert swedish translation to SVN state
  * Regenerate translations from .desktop files
* Wed May 31 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170531.7e7f57d:
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Catalan)
  * Rename appstream.po to appstreamdata.po to avoid conflict
  * Rename appstream -> appstreamdata in tar2po
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Spanish)
  * Translated using Weblate (French)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Portuguese (Brazil))
* Tue May 30 2017 fvogt@suse.com
- Change License: to MIT
* Thu May 18 2017 fvogt@suse.com
- Also generate other mo files
* Thu May 18 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170518.2205c8c:
  * tar2po: Escape newline in gettext strings correctly
  * Merge POT files into PO files to not lose translations
  * Update translations with latest changes
* Thu May 18 2017 fvogt@suse.com
- Add gettext-runtime and xz BuildRequires
* Thu May 18 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170517.b889563:
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Catalan)
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Catalan)
* Fri Feb  3 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170202.0c8d823:
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Slovak)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Italian)
  * Translated using Weblate (Catalan)
* Tue Jan 10 2017 opensuse-packaging@opensuse.org
- Update to version 84.87.20170109.20ca54c:
  * new data from upstream
* Tue Jan 10 2017 sriedel@suse.de
- Update package for new GIT repo.
* Mon Nov  7 2016 ke@suse.de
- Update translations from SVN.
* Tue Oct 25 2016 ke@suse.de
- Remove Cyrillic strings from the Swedish (sv) translations.
- Update translations from SVN.
* Wed Oct 12 2016 ke@suse.de
- Update translations from SVN.
* Wed Oct  7 2015 coolo@suse.com
- update from SVN
* Sat Jul 11 2015 antoine.belvire@laposte.net
- Set version to 13.2.
- Update translations.
* Tue Oct 28 2014 ke@suse.de
- Update translations.
* Tue Oct 14 2014 ke@suse.de
- Update translations.
* Wed Oct  8 2014 ke@suse.de
- Update translations.
-  PREPARE_PACKAGE: Set the opensuse.org translation SVN.
-  PREPARE_PACKAGE: ALso filter "\\ ".
* Wed Oct 30 2013 ke@suse.de
- Update translations.
* Thu Oct 24 2013 ke@suse.de
- Update translations.
* Thu Oct 17 2013 ke@suse.de
- Update translations.
* Mon Oct  7 2013 ke@suse.de
- Update translations.
* Mon Sep 30 2013 ke@suse.de
- Update translations.
* Thu Sep 26 2013 ke@suse.de
- Update translations.
* Wed Sep 18 2013 ke@suse.de
- Update translations.
* Wed Sep 11 2013 ke@suse.de
- Set version to 13.1.
- Update translations.
* Thu Feb 14 2013 ke@suse.de
- Update translations.
* Mon Feb  4 2013 ke@suse.de
- Update translations.
* Thu Jan 31 2013 ke@suse.de
- Set version to 12.3.
- Update translations.
* Thu Jan 17 2013 ke@suse.de
- Update translations.
* Fri Aug 24 2012 ke@suse.de
- Update translations.
* Tue Aug 21 2012 ke@suse.de
- Update translations; bnc#774339 (partially).
* Fri Aug 17 2012 ke@suse.de
- Update translations.
* Mon Aug 13 2012 ke@suse.de
- Update translations.
* Fri Aug  3 2012 ke@suse.de
- Update translations.
* Fri Jul  6 2012 ke@suse.de
- Update translations.
* Fri Jun 22 2012 ke@suse.de
- Update translations.
* Fri Jun  8 2012 ke@suse.de
- PREPARE_PACKAGE: Filter artificial "\ " strings.
- Update translations.
* Fri Jun  1 2012 ke@suse.de
- PREPARE_PACKAGE: Filter wrong \n.
- Update translations.
* Wed May 23 2012 ke@suse.de
- Update translations.
- Add URL.
* Wed May 16 2012 ke@suse.de
- Update translations.
* Mon May  7 2012 ke@suse.de
- Update translations.
* Fri Apr 20 2012 ke@suse.de
- Set version to 12.2.
- Update translations.
- PREPARE_PACKAGE: do not allow msgattrib to break long lines (use
  - -width 1000).
* Fri Nov  4 2011 ke@suse.de
- Update translations.
* Fri Oct 28 2011 ke@suse.de
- Update translations.
* Wed Oct 26 2011 ke@suse.de
- Update translations.
* Wed Oct 19 2011 ke@suse.de
- Update translations.
* Thu Oct 13 2011 ke@suse.de
- Update translations.
* Fri Oct  7 2011 ke@suse.de
- Update translations.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Fri Sep 16 2011 ke@suse.de
- Update translations.
* Fri Aug 26 2011 ke@suse.de
- Update translations.
* Fri Aug  5 2011 ke@suse.de
- Update translations.
* Fri Jun 17 2011 ke@suse.de
- set version to 12.1.
- update translations.
* Fri May 27 2011 ke@suse.de
- update translations.
* Fri Feb 25 2011 ke@suse.de
- update translations.
* Thu Feb 17 2011 ke@suse.de
- update translations.
* Fri Feb 11 2011 ke@suse.de
- update translations.
* Fri Jan 28 2011 coolo@novell.com
- glib2 is too low level to supplement a "desktop"
* Mon Jan 10 2011 ke@suse.de
- update translations.
* Mon Jan  3 2011 dmueller@suse.de
- bump version to 11.4
* Fri Nov 19 2010 ke@suse.de
- update translations.
* Fri Oct 29 2010 ke@suse.de
- update translations.
* Fri Oct  8 2010 ke@suse.de
- update translations.
* Thu Sep 30 2010 ke@suse.de
- update translations.
* Mon Jul  5 2010 ke@suse.de
- update translations.
* Fri Jun 25 2010 ke@suse.de
- update translations.
* Fri Jun 11 2010 ke@suse.de
- update translations.
* Fri Jun  4 2010 ke@suse.de
- update translations.
* Fri May 28 2010 ke@suse.de
- update translations.
* Fri May 14 2010 ke@suse.de
- Update translations.
* Fri May  7 2010 ke@suse.de
- Update translations.
* Fri Apr 16 2010 ke@suse.de
- Update translations.
* Fri Mar 19 2010 ke@suse.de
- Update translations.
* Thu Jan 28 2010 ke@suse.de
- Reference Berlios SVN.
* Thu Jan 14 2010 ke@suse.de
- update translations for Factory (-> 11.3).
- now also "supplements:  bundle-lang-other"; bnc#555257.
* Thu Oct 29 2009 ke@suse.de
- update translations for 11.2 RC2.
* Wed Oct 21 2009 ke@suse.de
- update translations for 11.2 RC2.
- work around a whitespace issue where YCC is affected; bnc#538245.
* Fri Oct  9 2009 ke@suse.de
- update translations for 11.2. RC1.
* Mon Oct  5 2009 ke@suse.de
- update translations, post 11.2 M8.
- Fix bugs bnc#538875 and bnc#539920 (partially).
* Thu Sep 24 2009 ke@suse.de
- update translations for 11.2. M8.
* Thu Sep 17 2009 ke@suse.de
- update translations from suse-i18n--see bnc#538245..
* Mon Aug 17 2009 ke@suse.de
- update translations from suse-i18n.
* Mon Aug 10 2009 ke@suse.de
- update translations from suse-i18n.
* Tue Jun 16 2009 ke@suse.de
- update translations.
- add 'be'.
- PREPARE_PACKAGE: quote '&' in file names (ctxt).
* Fri May 15 2009 ke@suse.de
- update translations.
* Thu Mar 19 2009 ke@suse.de
- update translations.
- PREPARE_PACKAGE: Skip missing entries.mo files.
* Fri Feb 27 2009 coolo@suse.de
- remove sr@Latn (also from svn)
* Fri Feb 27 2009 coolo@suse.de
- switch back to openSUSE translations
* Mon Dec 15 2008 ke@suse.de
- update translations for SLE11.
* Sat Nov 29 2008 coolo@suse.de
- update translations.
* Fri Nov 14 2008 ke@suse.de
- update translations.
* Sat Nov  8 2008 coolo@suse.de
- update translations
* Fri Nov  7 2008 ke@suse.de
- update translations.
* Thu Nov  6 2008 coolo@suse.de
- update translations
* Mon Oct 27 2008 coolo@suse.de
- initial package split out of update-desktop-files
